@@ -50,11 +50,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 package_name="apache-airflow",
                 function=_run_finished_callback,
                 supported_versions=[
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer",
                 ],
                 destination_path="airflow.models.taskinstance.TaskInstance",
             ),
@@ -69,11 +70,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 function=handle_callback,
                 supported_versions=[
                     "1.10.15",
-                    "2.2.3+composer",
-                    "2.2.3",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer",
                 ],
                 destination_path="airflow.models.dag.DAG",
             ),
@@ -106,12 +108,13 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 function=_add_auth,
                 supported_versions=[
                     "1.10.15",
-                    "1.10.15+composer",
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
+                    "1.10.15+composer",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer",
                 ],
                 destination_path="openlineage.client.OpenLineageClient",
             ),
@@ -120,19 +123,20 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 function=get_or_create_openlineage_client,
                 supported_versions=[
                     "1.10.15",
-                    "1.10.15+composer",
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
+                    "1.10.15+composer",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer",
                 ],
                 destination_path="openlineage.airflow.adapter.OpenLineageAdapter",
             ),
             AlvinPatch(
                 package_name="apache-airflow",
                 function=update_state,
-                supported_versions=["2.2.3", "2.2.5", "2.2.3+composer"],
+                supported_versions=["2.2.3", "2.2.5", "2.2.3+composer", "2.2.5+composer"],
                 destination_path="airflow.models.dagrun.DagRun",
             ),
             AlvinPatch(
@@ -156,12 +160,13 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 function=get_all_dagmodels,
                 supported_versions=[
                     "1.10.15",
-                    "1.10.15+composer",
                     "2.1.4",
-                    "2.1.4+composer",
                     "2.2.3",
+                    "2.2.5",
+                    "1.10.15+composer",
+                    "2.1.4+composer",
                     "2.2.3+composer",
-                    "2.2.5"
+                    "2.2.5+composer"
                 ],
                 destination_path="airflow.models.dag.DagModel",
             ),
@@ -175,12 +180,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
             AlvinPipelineCreator(
                 package_name="apache-airflow",
                 function=create_alvin_dag_current,
-                supported_versions=["2.2.3", "2.1.4", "2.2.5"],
+                supported_versions=["2.1.4", "2.2.3", "2.2.5"],
             ),
             AlvinPipelineCreator(
                 package_name="apache-airflow",
                 function=create_alvin_dag_google_composer,
-                supported_versions=["2.2.3+composer", "2.1.4+composer"],
+                supported_versions=["2.1.4+composer", "2.2.3+composer", "2.2.5+composer"],
             ),
             AlvinPipelineCreator(
                 package_name="apache-airflow",
@@ -196,11 +201,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 env_name="OPENLINEAGE_EXTRACTOR_BigQueryExecuteQueryOperator",
                 env_value="alvin_integration.producers.airflow.lineage.extractors.bigquery.AlvinBigQueryExtractor",
                 supported_versions=[
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer",
                 ],
             ),
             AlvinLineageConfig(
@@ -208,11 +214,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 env_name="OPENLINEAGE_EXTRACTOR_BigQueryInsertJobOperator",
                 env_value="alvin_integration.producers.airflow.lineage.extractors.bigquery.AlvinBigQueryExtractor",
                 supported_versions=[
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer"
                 ],
             ),
             # We have some customers that still use the BigQueryOperator on Airflow V2
@@ -224,11 +231,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 env_name="OPENLINEAGE_EXTRACTOR_BigQueryOperator",
                 env_value="alvin_integration.producers.airflow.lineage.extractors.bigquery.AlvinBigQueryExtractor",
                 supported_versions=[
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer"
                 ],
             ),
             AlvinLineageConfig(
@@ -248,11 +256,12 @@ class AirflowProducerConfig(AbstractProducerConfig):
                 env_name="OPENLINEAGE_EXTRACTOR_SnowflakeOperator",
                 env_value="alvin_integration.producers.airflow.lineage.extractors.snowflake.AlvinSnowflakeExtractor",
                 supported_versions=[
-                    "2.2.3",
-                    "2.2.3+composer",
                     "2.1.4",
+                    "2.2.3",
                     "2.2.5",
                     "2.1.4+composer",
+                    "2.2.3+composer",
+                    "2.2.5+composer"
                 ],
             ),
         ]
